### SecretChord

Generate robust and beautiful Chord Diagrams with pure matplotlib.

`matplotlib` wrapper for [Chord](https://en.wikipedia.org/wiki/Chord_diagram)
Diagrams. This is a part
of [SecretPlot](https://github.com/secretBiology/SecretPlots)
project.
